"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const password_validator_1 = __importDefault(require("password-validator"));
const Errors_1 = require("../Errors");
const minLength = 10;
const maxLength = 100;
const schema = new password_validator_1.default()
    .is().min(minLength)
    .is().max(maxLength)
    .has().uppercase()
    .has().lowercase()
    .has().digits()
    .has().not().spaces();
const validatePassword = (password) => {
    const failedRules = schema.validate(password, { list: true });
    if (failedRules.includes("min"))
        throw new Errors_1.ShortPasswordError(minLength);
    if (failedRules.includes("max"))
        throw new Errors_1.LongPasswordError(maxLength);
    if (failedRules.includes("uppercase"))
        throw new Errors_1.PasswordWithoutUppercaseError();
    if (failedRules.includes("lowercase"))
        throw new Errors_1.PasswordWithoutLowercaseError();
    if (failedRules.includes("digits"))
        throw new Errors_1.PasswordWithoutDigitsError();
    if (failedRules.includes("spaces"))
        throw new Errors_1.PasswordWithSpacesError();
};
exports.validatePassword = validatePassword;
